PythonProxyHandler (py4j-java 0.10.0 API)
Date: 2016-04-18

py4j.reflection

## Class PythonProxyHandler

- java.lang.Object
- - py4j.reflection.PythonProxyHandler

- All Implemented Interfaces:
    java.lang.reflect.InvocationHandler

      public class PythonProxyHandler
      extends java.lang.Object
      implements java.lang.reflect.InvocationHandler

  A PythonProxyHandler is used in place of a Python object. Python programs can send Python objects that implements a Java interface to the JVM: these Python objects are represented by dynamic proxies with a PythonProxyHandler.

- - ### Field Summary

    Fields
    Modifier and Type | Field and Description
    --- | ---
    `static java.lang.String` | `CALL_PROXY_COMMAND_NAME`
    `static java.lang.String` | `GARBAGE_COLLECT_PROXY_COMMAND_NAME`

  - ### Constructor Summary

    Constructors
    Constructor and Description
    `PythonProxyHandler(java.lang.String id, Gateway gateway)`

  - ### Method Summary

    All Methods Instance Methods Concrete Methods
    Modifier and Type | Method and Description
    --- | ---
    `protected void` | `finalize()`
    `java.lang.Object` | `invoke(java.lang.Object proxy, java.lang.reflect.Method method, java.lang.Object[] args)`

    - ### Methods inherited from class java.lang.Object

      `clone, equals, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

- - ### Field Detail

    - #### CALL_PROXY_COMMAND_NAME

          public static final java.lang.String CALL_PROXY_COMMAND_NAME

      See Also:
        Constant Field Values

    - #### GARBAGE_COLLECT_PROXY_COMMAND_NAME

          public static final java.lang.String GARBAGE_COLLECT_PROXY_COMMAND_NAME

      See Also:
        Constant Field Values

  - ### Constructor Detail

    - #### PythonProxyHandler

          public PythonProxyHandler(java.lang.String id,
                                    Gateway gateway)

  - ### Method Detail

    - #### finalize

          protected void finalize()
                           throws java.lang.Throwable

      Overrides:
        `finalize` in class `java.lang.Object`
      Throws:
        `java.lang.Throwable`

    - #### invoke

          public java.lang.Object invoke(java.lang.Object proxy,
                                         java.lang.reflect.Method method,
                                         java.lang.Object[] args)
                                  throws java.lang.Throwable

      Specified by:
        `invoke` in interface `java.lang.reflect.InvocationHandler`
      Throws:
        `java.lang.Throwable`